@@ -2,15 +2,14 @@
 #
 # This file is part of DataCite.
 #
-# Copyright (C) 2015 CERN.
+# Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2018 Center for Open Science.
 #
 # DataCite is free software; you can redistribute it and/or modify it
 # under the terms of the Revised BSD License; see LICENSE file for
 # more details.
 
-"""Module for making requests to the DataCite MDS API."""
-
-from __future__ import absolute_import, print_function
+"""Module for making requests to the DataCite API."""
 
 import ssl
 
@@ -18,7 +17,6 @@ import requests
 from requests.auth import HTTPBasicAuth
 from requests.exceptions import RequestException
 
-from ._compat import string_types, text_type
 from .errors import HttpError
 
 
@@ -27,7 +25,7 @@ class DataCiteRequest(object):
 
     :param base_url: Base URL for all requests.
     :param username: HTTP Basic Authentication Username
-    :param password: HTTP Basic Authentication Passsword
+    :param password: HTTP Basic Authentication Password
     :param default_params: A key/value-mapping which will be converted into a
         query string on all requests.
     :param timeout: Connect and read timeout in seconds. Specify a tuple
@@ -35,15 +33,15 @@ class DataCiteRequest(object):
     """
 
     def __init__(self, base_url=None, username=None, password=None,
-                 default_params={}, timeout=None):
+                 default_params=None, timeout=None):
         """Initialize request object."""
         self.base_url = base_url
         self.username = username
-        self.password = password
-        self.default_params = default_params
+        self.password = password.encode('utf8')
+        self.default_params = default_params or {}
         self.timeout = timeout
 
-    def request(self, url, method='GET', body=None, params={}, headers={}):
+    def request(self, url, method='GET', body=None, params=None, headers=None):
         """Make a request.
 
         If the request was successful (i.e no exceptions), you can find the
@@ -55,6 +53,9 @@ class DataCiteRequest(object):
         :param params: Request parameters
         :param headers: Request headers
         """
+        params = params or {}
+        headers = headers or {}
+
         self.data = None
         self.code = None
 
@@ -64,7 +65,7 @@ class DataCiteRequest(object):
         if self.base_url:
             url = self.base_url + url
 
-        if body and isinstance(body, text_type):
+        if body and isinstance(body, str):
             body = body.encode('utf-8')
 
         request_func = getattr(requests, method.lower())
@@ -76,30 +77,33 @@ class DataCiteRequest(object):
 
         if method == 'POST':
             kwargs['data'] = body
+        if method == 'PUT':
+            kwargs['data'] = body
         if self.timeout is not None:
             kwargs['timeout'] = self.timeout
 
         try:
-            res = request_func(url, **kwargs)
-            self.code = res.status_code
-            self.data = res.content
-            if not isinstance(body, string_types):
-                self.data = self.data.decode('utf8')
+            return request_func(url, **kwargs)
         except RequestException as e:
             raise HttpError(e)
         except ssl.SSLError as e:
             raise HttpError(e)
 
-    def get(self, url, params={}, headers={}):
+    def get(self, url, params=None, headers=None):
         """Make a GET request."""
         return self.request(url, params=params, headers=headers)
 
-    def post(self, url, body=None, params={}, headers={}):
+    def post(self, url, body=None, params=None, headers=None):
         """Make a POST request."""
         return self.request(url, method="POST", body=body, params=params,
                             headers=headers)
 
-    def delete(self, url, params={}, headers={}):
+    def put(self, url, body=None, params=None, headers=None):
+        """Make a PUT request."""
+        return self.request(url, method="PUT", body=body, params=params,
+                            headers=headers)
+
+    def delete(self, url, params=None, headers=None):
         """Make a DELETE request."""
         return self.request(url, method="DELETE", params=params,
                             headers=headers)
